@@ -2,6 +2,8 @@
 use winit::platform::startup_notify::{
     self, EventLoopExtStartupNotify, WindowAttributesExtStartupNotify,
 };
+#[cfg(not(any(target_os = "macos", windows)))]
+use winit::window::ActivationToken;
 
 #[cfg(all(not(feature = "x11"), not(any(target_os = "macos", windows))))]
 use winit::platform::wayland::WindowAttributesExtWayland;
@@ -20,9 +22,8 @@ use std::fmt::{self, Display, Formatter};
 
 #[cfg(target_os = "macos")]
 use {
-    cocoa::appkit::NSColorSpace,
-    cocoa::base::{id, nil, NO, YES},
-    objc::{msg_send, sel, sel_impl},
+    objc2_app_kit::{NSColorSpace, NSView},
+    objc2_foundation::is_main_thread,
     winit::platform::macos::{OptionAsAlt, WindowAttributesExtMacOS, WindowExtMacOS},
 };
 
@@ -39,13 +40,14 @@ use winit::window::{
 
 use alacritty_terminal::index::Point;
 
+use crate::cli::WindowOptions;
 use crate::config::window::{Decorations, Identity, WindowConfig};
 use crate::config::UiConfig;
 use crate::display::SizeInfo;
 
 /// Window icon for `_NET_WM_ICON` property.
 #[cfg(all(feature = "x11", not(any(target_os = "macos", windows))))]
-static WINDOW_ICON: &[u8] = include_bytes!("../../extra/logo/compat/alacritty-term.png");
+const WINDOW_ICON: &[u8] = include_bytes!("../../extra/logo/compat/alacritty-term.png");
 
 /// This should match the definition of IDI_ICON from `alacritty.rc`.
 #[cfg(windows)]
@@ -125,9 +127,7 @@ impl Window {
         event_loop: &ActiveEventLoop,
         config: &UiConfig,
         identity: &Identity,
-        #[rustfmt::skip]
-        #[cfg(target_os = "macos")]
-        tabbing_id: &Option<String>,
+        _options: &mut WindowOptions,
         #[rustfmt::skip]
         #[cfg(all(feature = "x11", not(any(target_os = "macos", windows))))]
         x11_visual: Option<X11VisualInfo>,
@@ -139,7 +139,7 @@ impl Window {
             #[cfg(all(feature = "x11", not(any(target_os = "macos", windows))))]
             x11_visual,
             #[cfg(target_os = "macos")]
-            tabbing_id,
+            &_options.window_tabbing_id.take(),
         );
 
         if let Some(position) = config.window.position {
@@ -148,7 +148,12 @@ impl Window {
         }
 
         #[cfg(not(any(target_os = "macos", windows)))]
-        if let Some(token) = event_loop.read_token_from_env() {
+        if let Some(token) = _options
+            .activation_token
+            .take()
+            .map(ActivationToken::from_raw)
+            .or_else(|| event_loop.read_token_from_env())
+        {
             log::debug!("Activating window with token: {token:?}");
             window_attributes = window_attributes.with_activation_token(token);
 
@@ -170,7 +175,8 @@ impl Window {
             .with_transparent(true)
             .with_blur(config.window.blur)
             .with_maximized(config.window.maximized())
-            .with_fullscreen(config.window.fullscreen());
+            .with_fullscreen(config.window.fullscreen())
+            .with_window_level(config.window.level.into());
 
         let window = event_loop.create_window(window_attributes)?;
 
@@ -224,6 +230,12 @@ impl Window {
         self.window.set_visible(visibility);
     }
 
+    #[cfg(target_os = "macos")]
+    #[inline]
+    pub fn focus_window(&self) {
+        self.window.focus_window();
+    }
+
     /// Set the window title.
     #[inline]
     pub fn set_title(&mut self, title: String) {
@@ -445,16 +457,15 @@ impl Window {
     /// This prevents rendering artifacts from showing up when the window is transparent.
     #[cfg(target_os = "macos")]
     pub fn set_has_shadow(&self, has_shadows: bool) {
-        let ns_view = match self.raw_window_handle() {
-            RawWindowHandle::AppKit(handle) => handle.ns_view.as_ptr() as id,
+        let view = match self.raw_window_handle() {
+            RawWindowHandle::AppKit(handle) => {
+                assert!(is_main_thread());
+                unsafe { handle.ns_view.cast::<NSView>().as_ref() }
+            },
             _ => return,
         };
 
-        let value = if has_shadows { YES } else { NO };
-        unsafe {
-            let ns_window: id = msg_send![ns_view, window];
-            let _: id = msg_send![ns_window, setHasShadow: value];
-        }
+        view.window().unwrap().setHasShadow(has_shadows);
     }
 
     /// Select tab at the given `index`.
@@ -489,13 +500,15 @@ impl Window {
 
 #[cfg(target_os = "macos")]
 fn use_srgb_color_space(window: &WinitWindow) {
-    let ns_view = match window.window_handle().unwrap().as_raw() {
-        RawWindowHandle::AppKit(handle) => handle.ns_view.as_ptr() as id,
+    let view = match window.window_handle().unwrap().as_raw() {
+        RawWindowHandle::AppKit(handle) => {
+            assert!(is_main_thread());
+            unsafe { handle.ns_view.cast::<NSView>().as_ref() }
+        },
         _ => return,
     };
 
     unsafe {
-        let ns_window: id = msg_send![ns_view, window];
-        let _: () = msg_send![ns_window, setColorSpace: NSColorSpace::sRGBColorSpace(nil)];
+        view.window().unwrap().setColorSpace(Some(&NSColorSpace::sRGBColorSpace()));
     }
 }
