@@ -73,7 +73,7 @@ impl WindowContext {
         event_loop: &ActiveEventLoop,
         proxy: EventLoopProxy<Event>,
         config: Rc<UiConfig>,
-        options: WindowOptions,
+        mut options: WindowOptions,
     ) -> Result<Self, Box<dyn Error>> {
         let raw_display_handle = event_loop.display_handle().unwrap().as_raw();
 
@@ -83,7 +83,7 @@ impl WindowContext {
         // Windows has different order of GL platform initialization compared to any other platform;
         // it requires the window first.
         #[cfg(windows)]
-        let window = Window::new(event_loop, &config, &identity)?;
+        let window = Window::new(event_loop, &config, &identity, &mut options)?;
         #[cfg(windows)]
         let raw_window_handle = Some(window.raw_window_handle());
 
@@ -102,10 +102,9 @@ impl WindowContext {
             event_loop,
             &config,
             &identity,
+            &mut options,
             #[cfg(all(feature = "x11", not(any(target_os = "macos", windows))))]
             gl_config.x11_visual(),
-            #[cfg(target_os = "macos")]
-            &options.window_tabbing_id,
         )?;
 
         // Create context.
@@ -123,7 +122,7 @@ impl WindowContext {
         event_loop: &ActiveEventLoop,
         proxy: EventLoopProxy<Event>,
         config: Rc<UiConfig>,
-        options: WindowOptions,
+        mut options: WindowOptions,
         config_overrides: ParsedOptions,
     ) -> Result<Self, Box<dyn Error>> {
         let gl_display = gl_config.display();
@@ -135,10 +134,9 @@ impl WindowContext {
             event_loop,
             &config,
             &identity,
+            &mut options,
             #[cfg(all(feature = "x11", not(any(target_os = "macos", windows))))]
             gl_config.x11_visual(),
-            #[cfg(target_os = "macos")]
-            &options.window_tabbing_id,
         )?;
 
         // Create context.
